diff -purN u-boot-1.0.0/drivers/smc91111.c u-boot-1.0.0-a/drivers/smc91111.c
--- u-boot-1.0.0/drivers/smc91111.c	Mon Dec  1 11:51:23 2003
+++ u-boot-1.0.0-a/drivers/smc91111.c	Tue Sep 16 16:07:28 2003
@@ -52,7 +52,7 @@
  .    o   skeleton.c by Donald Becker ( becker@cesdis.gsfc.nasa.gov )
  .
  . History:
- .  06/19/03  Richard Woodruff Made u-boot environment aware and added mac addr checks. 
+ .      06/19/03  Richard Woodruff Made u-boot environment aware and added mac addr checks.
  .	10/17/01  Marco Hasewinkel Modify for DNP/1110
  .	07/25/01  Woojung Huh      Modify for ADS Bitsy
  .	04/25/01  Daris A Nevil    Initial public release through SMSC
@@ -202,7 +202,7 @@ static int smc_rcv(void);
  . If an EEPROM is present it really should be consulted.
 */
 int smc_get_ethaddr(bd_t *bd);
-int get_rom_mac(uchar *v_rom_mac);
+int get_rom_mac(char *v_rom_mac);
 
 /*
  ------------------------------------------------------------
@@ -212,14 +212,14 @@ int get_rom_mac(uchar *v_rom_mac);
  ------------------------------------------------------------
 */
 
-static unsigned char smc_mac_addr[] = {0x02, 0x80, 0xad, 0x20, 0x31, 0xb8};
+static char smc_mac_addr[] = {0x02, 0x80, 0xad, 0x20, 0x31, 0xb8};
 
 /*
  * This function must be called before smc_open() if you want to override
  * the default mac address.
  */
 
-void smc_set_mac_addr(const uchar *addr) {
+void smc_set_mac_addr(const char *addr) {
 	int i;
 
 	for (i=0; i < sizeof(smc_mac_addr); i++){
@@ -659,36 +659,6 @@ void smc_destructor()
 	PRINTK2(CARDNAME ":smc_destructor\n");
 }
 
-/*
- * If chip isn't there then report it.
- */ 
-
-static int smc_probe(void)
-{
-	int bank;
-	
-	bank =  SMC_inw (BANK_SELECT);
-	if ((bank & 0xFF00) != 0x3300)
-		return -1;
-	return 0;
-}
-
-/* 
- * Set MAC address even if smc_open is not called by u-boot. Its a good idea
- * for the mac to be set in the chip when the kernel starts (no eeprom case).
- */
-int eth_mac_config(bd_t *bd)
-{
-	int err, i;
-
-	err = smc_probe();
-        if(err >= 0){
-		SMC_SELECT_BANK (1);
-		smc_get_ethaddr (bd);
-		for (i = 0; i < 6; i++)
-			SMC_outb (smc_mac_addr[i], ADDR0_REG + i);
-	}
-}
 
 /*
  * Open and Initialize the board
@@ -702,26 +672,21 @@ static int smc_open (bd_t * bd)
 
 	PRINTK2 ("%s:smc_open\n", SMC_DEV_NAME);
 
-	err = smc_probe();
-        if(err >= 0)
-	{	
-		/* reset the hardware */
-		smc_reset ();
-		smc_enable ();
+	/* reset the hardware */
+	smc_reset ();
+	smc_enable ();
 
-		/* Configure the PHY */
+	/* Configure the PHY */
 #ifndef CONFIG_SMC91111_EXT_PHY
-		smc_phy_configure ();
+	smc_phy_configure ();
 #endif
 
-		/* conservative setting (10Mbps, HalfDuplex, no AutoNeg.) */
-/*		SMC_SELECT_BANK(0); */
-/*		SMC_outw(0, RPC_REG); */
-		SMC_SELECT_BANK (1);
-
-		err = smc_get_ethaddr (bd);	/* set smc_mac_addr, and sync it with u-boot globals */
-	}
+	/* conservative setting (10Mbps, HalfDuplex, no AutoNeg.) */
+/*	SMC_SELECT_BANK(0); */
+/*	SMC_outw(0, RPC_REG); */
+	SMC_SELECT_BANK (1);
 
+	err = smc_get_ethaddr (bd);	/* set smc_mac_addr, and sync it with u-boot globals */
 	if (err < 0) {
 		memset (bd->bi_enetaddr, 0, 6);	/* hack to make error stick! upper code will abort if not set */
 		return (-1);	/* upper code ignores this, but NOT bi_enetaddr */
@@ -1338,7 +1303,7 @@ static void smc_phy_configure ()
 	/* Re-Configure the Receive/Phy Control register */
 	SMC_outw (RPC_DEFAULT, RPC_REG);
 
-      smc_phy_configure_exit:;
+      smc_phy_configure_exit:
 
 }
 #endif /* !CONFIG_SMC91111_EXT_PHY */
@@ -1460,12 +1425,12 @@ int smc_get_ethaddr (bd_t * bd)
 	return (0);
 }
 
-int get_rom_mac (uchar *v_rom_mac)
+int get_rom_mac (char *v_rom_mac)
 {
 	int is_rom_present = 0;
 
 #ifdef HARDCODE_MAC	/* used for testing or to supress run time warnings */
-	uchar hw_mac_addr[] = { 0x02, 0x80, 0xad, 0x20, 0x31, 0xb8 };
+	char hw_mac_addr[] = { 0x02, 0x80, 0xad, 0x20, 0x31, 0xb8 };
 
 	memcpy (v_rom_mac, hw_mac_addr, 6);
 	return (1);
diff -purN u-boot-1.0.0/drivers/smc91111.h u-boot-1.0.0-a/drivers/smc91111.h
--- u-boot-1.0.0/drivers/smc91111.h	Mon Dec  1 11:51:23 2003
+++ u-boot-1.0.0-a/drivers/smc91111.h	Sun Oct 19 18:22:11 2003
@@ -49,7 +49,7 @@
  * in order to override the default mac address.
  */
 
-void smc_set_mac_addr(const uchar *addr);
+void smc_set_mac_addr(const char *addr);
 
 
 /* I want some simple types */
